@@ -118,7 +118,7 @@ class Progress:
             subtasks={s:1.0/float(len(subtasks)) for s,v in subtasks.items()}
         else:
             finalsum=msum*float(len(subtasks))/float(len(filtered))
-            subtasks={s:v/finalsum if v else 1.0/float(len(subtasks)) for s,v in subtasks.items()}
+            subtasks={s:v/finalsum if not v == None else 1.0/float(len(subtasks)) for s,v in subtasks.items()}
         def create_progress(n ,v):
             p = Progress(n, extra[n] if n in extra else {})
             (p.__parent, p.__parent_contrib) = (self, v)
